@@ -1,6 +1,6 @@
 package Lemonldap::NG::Handler::Main::Reload;
 
-our $VERSION = '2.18.0';
+our $VERSION = '2.19.0';
 
 package Lemonldap::NG::Handler::Main;
 
@@ -36,7 +36,9 @@ sub onReload {
 sub checkConf {
     my ( $class, $force ) = @_;
     $class->logger->debug("Check configuration for $class");
-    my $prm  = { local => !$force, localPrm => $class->localConfig };
+    my $prm    = { local => !$force, localPrm => $class->localConfig };
+    my $cfgNum = $class->confAcc->lastCfg();
+    $prm->{local} = 0 if $class->cfgNum and $cfgNum != $class->cfgNum;
     my $conf = $class->confAcc->getConf($prm);
     chomp $Lemonldap::NG::Common::Conf::msg;
 
@@ -84,12 +86,16 @@ sub checkConf {
                     $class->logger->error( "Underlying object can't load conf ("
                           . ref($obj)
                           . "->$sub)" );
+                    if ( $obj->can('error') ) {
+                        $Lemonldap::NG::Common::Conf::msg = $obj->error;
+                    }
                     return 0;
                 }
             }
         }
     }
     $class->checkTime( $conf->{checkTime} ) if $conf->{checkTime};
+    $class->checkMsg( $conf->{checkMsg} )   if $conf->{checkMsg};
     $class->lastCheck( time() );
     $class->logger->debug("$class: configuration is up to date");
     return 1;
@@ -131,6 +137,7 @@ sub reload {
 #      - timeoutActivityInterval
 #      - useRedirectOnError
 #      - useRedirectOnForbidden
+#      - useRedirectAjaxOnUnauthorized
 #      - useSafeJail
 #      (objects)
 #      - cipher  # Lemonldap::NG::Common::Crypto object
@@ -161,6 +168,11 @@ sub reload {
 #      - outputPostData
 # - aliasInit():
 #      - vhostAlias
+# - oauth2Init():
+#      - oauth2Options
+# - msgBrokerInit():
+#      - msgBrokerWriter
+#      - msgBrokerReader
 #
 # The *Init() methods can be run in any order,
 # but jailInit must be run first because $tsv->{jail}
@@ -175,7 +187,8 @@ sub configReload {
 
     foreach my $sub (
         qw( defaultValuesInit jailInit portalInit locationRulesInit
-        sessionStorageInit headersInit postUrlInit aliasInit oauth2Init )
+        sessionStorageInit headersInit postUrlInit aliasInit
+        oauth2Init msgBrokerInit )
       )
     {
         $class->logger->debug("Process $$ calls $sub");
@@ -214,6 +227,8 @@ sub defaultValuesInit {
         useSafeJail  httpOnly   whatToTrace        handlerInternalCache
         handlerServiceTokenTTL  customToTrace      lwpOpts lwpSslOpts
         authChoiceAuthBasic     authChoiceParam    upgradeSession
+        hashedSessionStore      eventQueueName     eventStatus
+        statusQueueName useRedirectAjaxOnUnauthorized
         )
       );
 
@@ -414,7 +429,6 @@ sub sessionStorageInit {
                       keys %{ $class->tsv->{sessionCacheOptions} // {} }
                 ) . '}';
             }
-            $class->tsv->{statusPipe}->print("RELOADCACHE $params\n");
         }
     }
     return 1;
@@ -523,14 +537,16 @@ sub conditionSub {
             $url
             ? (
                 sub {
-                    $_[1]->{_logout} = $url;
+                    my ( $req, $session ) = @_;
+                    $session->{_logout} = $url;
                     return 0;
                 },
                 0
               )
             : (
                 sub {
-                    $_[1]->{_logout} = $class->tsv->{portal}->();
+                    my ( $req, $session ) = @_;
+                    $session->{_logout} = $class->tsv->{portal}->($req);
                     return 0;
                 },
                 0
@@ -610,6 +626,18 @@ sub oauth2Init {
     return 1;
 }
 
+sub msgBrokerInit {
+    my ( $class, $conf ) = @_;
+
+    my $brokerClass = $conf->{messageBroker} || '::NoBroker';
+    $brokerClass =~ s/^::/Lemonldap::NG::Common::MessageBroker::/;
+    eval "require $brokerClass";
+    die $@ if $@;
+    $class->tsv->{msgBrokerReader} = $brokerClass->new( $conf, $class->logger );
+    $class->tsv->{msgBrokerReader}->subscribe( $conf->{eventQueueName} );
+    $class->tsv->{msgBrokerWriter} = $brokerClass->new( $conf, $class->logger );
+}
+
 sub substitute {
     my ( $class, $expr ) = @_;
     $expr //= '';
@@ -634,6 +662,10 @@ sub substitute {
     # handle inSubnet
     $expr =~ s/\binSubnet\(([^)]*)\)/ipInSubnet(\$r->{env}->{REMOTE_ADDR},$1)/g;
 
+    # handle inSubnet
+    $expr =~
+      s/\binDomain\(([^)]*)\)/inDomain_internal(\$r->{env}->{HTTP_HOST},$1)/g;
+
     return $expr;
 }
 
