@@ -6,7 +6,7 @@ use strict;
 use Mouse;
 use Lemonldap::NG::Handler::Server::Main;
 
-our $VERSION = '2.0.6';
+our $VERSION = '2.17.0';
 
 extends 'Lemonldap::NG::Handler::PSGI';
 
@@ -17,7 +17,7 @@ sub init {
 }
 
 ## @method void _run()
-# Return a subroutine that call _logAuthTrace() and tranform redirection
+# Return a subroutine that call _authAndTrace() and tranform redirection
 # response code from 302 to 401 (not authenticated) ones. This is required
 # because Nginx "auth_request" parameter does not accept it. The Nginx
 # configuration file should transform them back to 302 using:
@@ -28,18 +28,18 @@ sub init {
 #@return subroutine that will be called to manage FastCGI queries
 sub _run {
     my $self = shift;
-    return sub {
-        my $req = $_[0];
-        $self->logger->debug('New request');
-        my $res = $self->_logAuthTrace(
-            Lemonldap::NG::Common::PSGI::Request->new($req) );
+    return $self->psgiAdapter(
+        sub {
+            my $req = $_[0];
+            my $res = $self->_authAndTrace($req);
 
-        # Transform 302 responses in 401 since Nginx refuse it
-        if ( $res->[0] == 302 or $res->[0] == 303 ) {
-            $res->[0] = 401;
+            # Transform 302 responses in 401 since Nginx refuse it
+            if ( $res->[0] == 302 or $res->[0] == 303 ) {
+                $res->[0] = 401;
+            }
+            return $res;
         }
-        return $res;
-    };
+    );
 }
 
 ## @method PSGI-Response handler()
